@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Alien;
 our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Use Alien::Base with Dist::Zilla
-$Dist::Zilla::Plugin::Alien::VERSION = '0.018';
+$Dist::Zilla::Plugin::Alien::VERSION = '0.019';
 use Moose;
 extends 'Dist::Zilla::Plugin::ModuleBuild';
 with 'Dist::Zilla::Role::PrereqSource', 'Dist::Zilla::Role::FileGatherer';
@@ -278,7 +278,7 @@ Dist::Zilla::Plugin::Alien - Use Alien::Base with Dist::Zilla
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -297,7 +297,7 @@ In your I<dist.ini>:
   pattern = myapp-([\d\.]+)\.tar\.gz
 
   # commands used to build (optional)
-  build_command = %pconfigure --prefix=%s
+  build_command = %c --prefix=%s
   # ...
 
   # commands uses to install (optional)
@@ -361,7 +361,7 @@ The ordered sequence of commands used to build the distribution (passed to the
 C<alien_build_commands> option). This is optional.
 
   # configure then make
-  build_command = %pconfigure --prefix=%s
+  build_command = %c --prefix=%s
   build_command = make
 
 =head2 install_command
